# pgpq

![CI](https://github.com/adriangb/pgpq/actions/workflows/python.yaml/badge.svg)

Proof of concept stage library for loading Parquet files into PostgreSQL directly by converting a stream of Arrow RecordBatches into PostgreSQL's binary format.
There's currently bugs and it's slow!
